@@ -335,7 +335,7 @@ $ret = main_get_entry($search_dn, $filter, array(),
 /* LDAP˼ */
 if ($ret != LDAP_OK) {
     $sys_err = TRUE;
-    $err_msg = htmlspecialchars($err_msg);
+    $err_msg = escape_html($err_msg);
     result_log(OPERATION . ":NG:" . $log_msg);
     syserr_display();
     exit (1);
@@ -356,7 +356,7 @@ $dispml = $result[0]["$dispmlatt"][0];
 /* ᡼륢ɥ쥹ݻ */
 $newaddr = "";
 if (isset($_POST["newaddr"])) {
-    $newaddr = htmlspecialchars($_POST["newaddr"]);
+    $newaddr = escape_html($_POST["newaddr"]);
 }
 
 $mailaddrs = "";
@@ -369,14 +369,14 @@ if (isset($result[0]["mailForwardingAddr"])) {
     /* ᡼륢ɥ쥹Υȥ򣱤ĤļɽѤ˲ù */
     foreach($result[0]["mailForwardingAddr"] as $i) {
         $addr = $i;
-        $addr = htmlspecialchars($addr);
+        $addr = escape_html($addr);
         $mailaddrs .= "<option value=\"$addr\">$addr" . "\n";
     }
 }
 
 /* ͤ򥻥å */
 set_tag_common($tag, "");
-$tag["<<MLADDR>>"] = $dispml = htmlspecialchars($dispml);
+$tag["<<MLADDR>>"] = $dispml = escape_html($dispml);
 $tag["<<HIDDEN>>"] = "<input type='hidden' name='mladdr' value='$enc_ml'>";
 $tag["<<NEWADDR>>"] = $newaddr;
 $tag["<<MAILADDRS>>"] = $mailaddrs;
